module Frizzle
  class Base
    include Singleton
    include HTTParty

    API_VERSION = "1.2".freeze

    base_uri "http://api.transloc.com/#{API_VERSION}"

    @default_geo_radius = 100

    class << self

      def default_geo_radius=(radius)
        @default_geo_radius = radius
      end

      def default_geo_radius
        @default_geo_radius || Frizzle::Base.default_geo_radius
      end

      def init_settings(options={})
        {
          :headers => {
            "User-Agent" => "frizzle-ruby-#{Frizzle::VERSION}",
            "Content-Type" => "application/json",
            "Accept" => "application/json"
          }
        }.deep_merge(options)
      end

      def fetch(url, options = {})
        options = self.init_settings(options)
        response = get(url, options)
        if response.success?
          response.parsed_response['data']
        elsif response.code == 403
          raise "TransLoc API limit: #{response.response}"
        else
          raise TransLocAPIError.new, "#{response}"
        end
      end

      def is_numeric?(obj)
         obj.to_s.match(/\A[+-]?\d+?(\.\d+)?\Z/) == nil ? false : true
      end

      def formatted_list(list)
        if list.instance_of? Array
          list = list.join(',')
        end
        list.to_s
      end

      def formatted_geo_area(first_geo, second_geo=nil)
        return "#{first_geo.join(',')}|#{second_geo.join(',')}" if first_geo.instance_of?(Array) && second_geo.instance_of?(Array)
        return "#{first_geo.join(',')}|#{second_geo}"  if first_geo.instance_of?(Array) && !second_geo.nil?
        return "#{first_geo.join(',')}|#{self.default_geo_radius}" if first_geo.instance_of?(Array) && second_geo.nil?
        raise(ArgumentError, "Geo arguments do not match the required format")
      end
    end
  end
end